@@ -1,9 +1,9 @@
 module.exports = {
-  test: /\.svelte$/,
+  test: /\.svelte(\.erb)?$/,
   use: [{
     loader: 'svelte-loader',
     options: {
-      hotReload: true
+      hotReload: false
     }
   }],
 }
