@@ -13,11 +13,13 @@ describe('DevServer', () => {
     process.env.RAILS_ENV = 'development'
     process.env.WEBPACKER_DEV_SERVER_HOST = '0.0.0.0'
     process.env.WEBPACKER_DEV_SERVER_PORT = 5000
+    process.env.WEBPACKER_DEV_SERVER_DISABLE_HOST_CHECK = false
 
     const devServer = require('../dev_server')
     expect(devServer).toBeDefined()
     expect(devServer.host).toEqual('0.0.0.0')
     expect(devServer.port).toEqual('5000')
+    expect(devServer.disable_host_check).toBe(false)
   })
 
   test('with custom env prefix', () => {
